Find all references to known functions within an expression
find_calls.Rdfind_calls() recursively walks a parsed R expression and collects
the names of any functions that appear as either direct calls
(fun()) or bare name references (fun).
find_calls.Rdfind_calls() recursively walks a parsed R expression and collects
the names of any functions that appear as either direct calls
(fun()) or bare name references (fun).